@@ -1,13 +1,13 @@
 package Data::Clean::FromJSON;
 
-our $DATE = '2016-03-30'; # DATE
-our $VERSION = '0.32'; # VERSION
+our $DATE = '2016-04-14'; # DATE
+our $VERSION = '0.33'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 
-use parent qw(Data::Clean::Base);
+use parent qw(Data::Clean);
 
 sub new {
     my ($class, %opts) = @_;
@@ -43,7 +43,7 @@ Data::Clean::FromJSON - Clean data from JSON decoder
 
 =head1 VERSION
 
-This document describes version 0.32 of Data::Clean::FromJSON (from Perl distribution Data-Clean-JSON), released on 2016-03-30.
+This document describes version 0.33 of Data::Clean::FromJSON (from Perl distribution Data-Clean-JSON), released on 2016-04-14.
 
 =head1 SYNOPSIS
 
@@ -65,13 +65,7 @@ This class can convert L<JSON::PP::Boolean> (or C<JSON::XS::Boolean>) objects to
 Return a singleton instance, with default options. Use C<new()> if you want to
 customize options.
 
-=head2 CLASS->new(%opts) => $obj
-
-Create a new instance. For list of known options, see L<Data::Clean::Base>.
-Data::Clean::FromJSON sets some defaults.
-
-    "JSON::PP::Boolean" => ['one_or_zero']
-    "JSON::XS::Boolean" => ['one_or_zero']
+=head2 CLASS->new() => $obj
 
 =head2 $obj->clean_in_place($data) => $cleaned
 
@@ -83,7 +77,7 @@ Clean $data. Clone $data first.
 
 =head1 FAQ
 
-=head2 Why am I getting 'Modification of a read-only value attempted at lib/Data/Clean/Base.pm line xxx'?
+=head2 Why am I getting 'Modification of a read-only value attempted at lib/Data/Clean.pm line xxx'?
 
 [2013-10-15 ] This is also from Data::Clone::clone() when it encounters
 JSON::{PP,XS}::Boolean objects. You can use clean_in_place() instead of
